@@ -3,7 +3,6 @@
 # Log-transformation
 
 log.est <- function(y) {
-    y=log(y)
+  y <- log(y)
   return(y)
 }
-
